@@ -18,6 +18,7 @@ class VacuumResult:
     imported_servers: dict[str, str]  # server_name -> source_location
     conflicts: list[dict[str, Any]]  # resolved conflicts
     errors: list[dict[str, str]]
+    skipped_servers: list[str]
 
 
 class SyncEngine:
@@ -293,12 +294,26 @@ class SyncEngine:
         # Location servers
         locations = self.config_manager.get_locations()
         for location in locations:
-            location_path = Path(location["path"])
-            config = self._read_json_config(location_path)
-            if config is not None:
-                status["location_servers"][location["name"]] = config.get("mcpServers", {})
+            # Handle CLI clients differently from file-based clients
+            if location.get("config_type") == "cli" or location["path"].startswith("cli:"):
+                client_id = (
+                    location["path"].replace("cli:", "")
+                    if location["path"].startswith("cli:")
+                    else location["name"]
+                )
+                cli_servers = self.config_manager.get_cli_mcp_servers(client_id)
+                if cli_servers is not None:
+                    status["location_servers"][location["name"]] = cli_servers
+                else:
+                    status["location_servers"][location["name"]] = {}
             else:
-                status["location_servers"][location["name"]] = "error"
+                # File-based client
+                location_path = Path(location["path"])
+                config = self._read_json_config(location_path)
+                if config is not None:
+                    status["location_servers"][location["name"]] = config.get("mcpServers", {})
+                else:
+                    status["location_servers"][location["name"]] = "error"
 
         return status
 
@@ -346,9 +361,11 @@ class SyncEngine:
         with open(path, "w") as f:
             json.dump(config, f, indent=2)
 
-    def vacuum_configs(self) -> "VacuumResult":
+    def vacuum_configs(
+        self, auto_resolve: str | None = None, skip_existing: bool = False
+    ) -> "VacuumResult":
         """Import existing MCP configs from all discovered locations"""
-        result = VacuumResult(imported_servers={}, conflicts=[], errors=[])
+        result = VacuumResult(imported_servers={}, conflicts=[], errors=[], skipped_servers=[])
 
         # Get all locations (excluding project .mcp.json files)
         locations = self.config_manager.get_locations()
@@ -366,13 +383,18 @@ class SyncEngine:
                         if server_name in discovered_servers:
                             # Conflict found - need to resolve
                             existing = discovered_servers[server_name]
-                            choice = self._resolve_conflict(
-                                server_name,
-                                existing["config"],
-                                existing["source"],
-                                server_config,
-                                location["name"],
-                            )
+                            if auto_resolve == "first":
+                                choice = "existing"
+                            elif auto_resolve == "last":
+                                choice = "new"
+                            else:
+                                choice = self._resolve_conflict(
+                                    server_name,
+                                    existing["config"],
+                                    existing["source"],
+                                    server_config,
+                                    location["name"],
+                                )
 
                             if choice == "new":
                                 discovered_servers[server_name] = {
@@ -415,13 +437,18 @@ class SyncEngine:
                 if server_name in discovered_servers:
                     # Conflict found - need to resolve
                     existing = discovered_servers[server_name]
-                    choice = self._resolve_conflict(
-                        server_name,
-                        existing["config"],
-                        existing["source"],
-                        server_config,
-                        location["name"],
-                    )
+                    if auto_resolve == "first":
+                        choice = "existing"
+                    elif auto_resolve == "last":
+                        choice = "new"
+                    else:
+                        choice = self._resolve_conflict(
+                            server_name,
+                            existing["config"],
+                            existing["source"],
+                            server_config,
+                            location["name"],
+                        )
 
                     if choice == "new":
                         discovered_servers[server_name] = {
@@ -454,6 +481,9 @@ class SyncEngine:
             global_config = self.config_manager.get_global_config()
 
             for server_name, server_info in discovered_servers.items():
+                if skip_existing and server_name in global_config.get("mcpServers", {}):
+                    result.skipped_servers.append(server_name)
+                    continue
                 global_config["mcpServers"][server_name] = server_info["config"]
                 result.imported_servers[server_name] = server_info["source"]
 
